Trait typenum::marker_traits::Bit [−][src]
The marker trait for compile time bits.
This trait should not be implemented for anything outside this crate.
The marker trait for compile time bits.
This trait should not be implemented for anything outside this crate.